@@ -15,7 +15,7 @@ import hashlib
 import shutil
 from datetime import datetime
 
-from .__init__ import __version__
+from .__init__ import VERSION
 
 import pygbag
 
@@ -31,7 +31,7 @@ CACHE_PATH = CACHE_ROOT / "web-cache"
 CACHE_VERSION = CACHE_ROOT / "version.txt"
 CACHE_APP = CACHE_ROOT / "web"
 
-cdn_dot = __version__.split(".")
+cdn_dot = VERSION.split(".")
 cdn_dot.pop()
 cdn_version = ".".join(cdn_dot)
 del cdn_dot
@@ -41,7 +41,7 @@ AUTO_REBUILD = True
 if devmode:
     sys.argv.remove("--dev")
     DEFAULT_PORT = 8666
-    DEFAULT_CDN = f"http://localhost:8000/archives/{cdn_version}/"
+    DEFAULT_CDN = f"http://localhost:8000/pygbag/0.0/"
     DEFAULT_TMPL = "static/wip.tmpl"
     print(
         f"""
@@ -57,10 +57,17 @@ if devmode:
     )
 
 else:
-    DEFAULT_CDN = f"https://pygame-web.github.io/archives/{cdn_version}/"
+    # use latest git build
+    if cdn_version == "0.0":
+        DEFAULT_CDN = f"https://pygame-web.github.io/pygbag/{cdn_version}/"
+    else:
+        DEFAULT_CDN = f"https://pygame-web.github.io/archives/{cdn_version}/"
     DEFAULT_PORT = 8000
     DEFAULT_TMPL = "default.tmpl"
 
+DEFAULT_WIDTH = 1280
+DEFAULT_HEIGHT = 720
+
 
 def set_args(program):
     global DEFAULT_SCRIPT
@@ -77,7 +84,8 @@ def set_args(program):
         app_folder = patharg.resolve()
         mainscript = DEFAULT_SCRIPT
 
-    sys.path.insert(0, str(app_folder))
+    # print("84: prepending to sys.path", str(app_folder) )
+    # sys.path.insert(0, str(app_folder))
 
     if patharg.suffix == "pyw":
         required.append("79: Error, no .pyw allowed use .py for python script")
@@ -105,7 +113,7 @@ def set_args(program):
 
 
 def cache_check(app_folder, devmode=False):
-    global CACHE_PATH, CACHE_APP, __version__
+    global CACHE_PATH, CACHE_APP, VERSION
 
     version_file = app_folder / CACHE_VERSION
 
@@ -119,8 +127,8 @@ def cache_check(app_folder, devmode=False):
         try:
             with open(version_file, "r") as file:
                 cache_ver = file.read()
-                if cache_ver != __version__:
-                    print(f"115: cache {cache_ver} mismatch, want {__version__}, cleaning ...")
+                if cache_ver != VERSION:
+                    print(f"115: cache {cache_ver} mismatch, want {VERSION}, cleaning ...")
                     clear_cache = True
         except:
             # something's wrong in cache structure, try clean it up
@@ -157,7 +165,7 @@ def cache_check(app_folder, devmode=False):
         make_cache_dirs()
 
         with open(version_file, "w") as file:
-            file.write(__version__)
+            file.write(VERSION)
 
     return build_dir, cache_dir
 
@@ -171,6 +179,9 @@ async def main_run(app_folder, mainscript, cdn=DEFAULT_CDN):
 
     sys.argv.pop()
 
+    if "--git" in sys.argv:
+        sys.argv.remove("--git")
+
     parser = argparse.ArgumentParser()
 
     print(
@@ -184,10 +195,17 @@ async def main_run(app_folder, mainscript, cdn=DEFAULT_CDN):
         metavar="ADDRESS",
         help="Specify alternate bind address [default: localhost]",
     )
+
     parser.add_argument(
-        "--directory",
-        default=build_dir.as_posix(),
-        help="Specify alternative directory [default:%s]" % build_dir,
+        "--width",
+        default=DEFAULT_WIDTH,
+        help="framebuffer width [default:%d]" % DEFAULT_WIDTH,
+    )
+
+    parser.add_argument(
+        "--height",
+        default=DEFAULT_HEIGHT,
+        help="framebuffer width [default:%d]" % DEFAULT_HEIGHT,
     )
 
     parser.add_argument(
@@ -195,6 +213,7 @@ async def main_run(app_folder, mainscript, cdn=DEFAULT_CDN):
         default="3.11",
         help="Specify python version [default:%s]" % "3.11",
     )
+
     parser.add_argument(
         "--app_name",
         default=app_folder.name,
@@ -225,8 +244,8 @@ async def main_run(app_folder, mainscript, cdn=DEFAULT_CDN):
 
     parser.add_argument(
         "--version",
-        default=__version__,
-        help="override prebuilt version path [default:%s]" % __version__,
+        default=VERSION,
+        help="override prebuilt version path [default:%s]" % VERSION,
     )
 
     parser.add_argument("--build", action="store_true", help="build only, do not run test server")
@@ -278,6 +297,14 @@ async def main_run(app_folder, mainscript, cdn=DEFAULT_CDN):
 
     args = parser.parse_args()
 
+    # when in browser IDE everything should be done in allowed folder
+
+    # force build directory in sourcefolder
+    args.directory = build_dir.as_posix()
+
+    # force cache directory to be inside build folder
+    args.cache = cache_dir.as_posix()
+
     app_name = app_folder.name.lower().replace(" ", ".")
 
     archfile = build_dir.joinpath(f"{app_name}.apk")
@@ -297,6 +324,9 @@ app_folder={app_folder}
 # artefacts directory
 build_dir={build_dir}
 
+# cache directory
+cache={cache_dir}
+
 # the window title and icon name
 app_name={app_name}
 
@@ -318,6 +348,8 @@ now packing application ....
         "cdn": args.cdn,
         "proxy": f"http://{args.bind}:{args.port}/",
         "xtermjs": "1",
+        "width": args.width,
+        "height": args.height,
         "ume_block": args.ume_block,
         "can_close": args.can_close,
         "archive": app_name,
@@ -327,7 +359,7 @@ now packing application ....
         "title": (args.title or app_name),
         "directory": app_name,
         "spdx": "cookiecutter.spdx",
-        "version": __version__,
+        "version": VERSION,
         "PYBUILD": args.PYBUILD,
     }
 
@@ -451,7 +483,6 @@ now packing application ....
             return
 
         elif not args.build:
-
             from . import testserver
 
             testserver.run_code_server(args, CC)
