@@ -35,10 +35,11 @@ VERB = True
 
 CACHE = None
 
-try:
-    from future_fstrings import fstring_decode
-except:
-    fstring_decode = False
+# does not support {x=}
+# try:
+#    from future_fstrings import fstring_decode
+# except:
+fstring_decode = False
 
 
 try:
@@ -58,11 +59,12 @@ class CodeHandler(SimpleHTTPRequestHandler):
         self.send_header("cross-origin-resource-policy:", "cross-origin")
         self.send_header("cross-origin-opener-policy", "cross-origin")
 
-        # buggy for https://pygame-web.github.io/archives/repo/index.json
+        # not valid for Atomics
         # self.send_header("cross-origin-embedder-policy", "unsafe-none")
 
-        # at least raise
-        # net::ERR_BLOCKED_BY_RESPONSE.NotSameOriginAfterDefaultedToSameOriginByCoep 200
+        # not -always- valid for Atomics (firefox)
+        # self.send_header("cross-origin-embedder-policy", "credentialless")
+
         self.send_header("cross-origin-embedder-policy", "require-corp")
 
         super().end_headers()
@@ -83,6 +85,12 @@ class CodeHandler(SimpleHTTPRequestHandler):
     def send_head(self):
         global VERB, CDN, PROXY, BCDN, BPROXY, AUTO_REBUILD
         path = self.translate_path(self.path)
+        print(
+            f"""
+
+{self.path=} {path=}"""
+        )
+
         f = None
         if os.path.isdir(path):
             parts = urllib.parse.urlsplit(self.path)
@@ -154,6 +162,16 @@ class CodeHandler(SimpleHTTPRequestHandler):
             cached = True
         else:
             cached = False
+
+        if path.endswith(".apk"):
+            if AUTO_REBUILD:
+                print()
+                AUTO_REBUILD()
+                print()
+            else:
+                print(f"{AUTO_REBUILD=} {path}")
+
+        if f is None:
             try:
                 f = open(path, "rb")
             except OSError:
@@ -163,15 +181,6 @@ class CodeHandler(SimpleHTTPRequestHandler):
             self.send_error(HTTPStatus.NOT_FOUND, "File not found")
             return None
 
-        if self.path.endswith(".apk"):
-            if AUTO_REBUILD:
-                print()
-                print(self.path)
-                AUTO_REBUILD()
-                print()
-            else:
-                print(f"{AUTO_REBUILD=} {self.path}")
-
         try:
             fs = os.fstat(f.fileno())
 
@@ -207,7 +216,7 @@ class CodeHandler(SimpleHTTPRequestHandler):
 
             file_size = fs[6]
 
-            if self.path.endswith(".py"):
+            if path.endswith(".py"):
                 if VERB:
                     print(" --> do_GET(%s)" % path)
                 if fstring_decode:
@@ -219,7 +228,7 @@ class CodeHandler(SimpleHTTPRequestHandler):
                 file_size = len(content)
                 f = io.BytesIO(content)
 
-            elif self.path.endswith(".json"):
+            elif path.endswith(".json"):
                 if VERB:
                     print()
                     print(self.path)
@@ -243,8 +252,6 @@ class CodeHandler(SimpleHTTPRequestHandler):
                 f = io.BytesIO(content)
 
             self.send_header("content-length", str(file_size))
-            # self.send_header("Access-Control-Allow-Origin", "*")
-            # self.send_header("Cross-Origin-Embedder-Policy", "require-corp")
 
             if not cached:
                 self.send_header("Last-Modified", self.date_time_string(fs.st_mtime))
